# AgilePy

## What is it?

Agile-py is a Python package to quickly kick off and python project.

## Main Features

- **Inintialize** project with `pyproject.toml`, `.pre-commit-config.yaml`, `.gitignore`, and vscode setting.

## Where to get it

Agile-py can be installed from PyPI using `pip`:

```bash
pip install agile-py
```

## Interface

### Initialize python project

```bash
agpy init
```
